==> eam-wshub-proxyclient-11.4-12-sources.jar: net/datastream/schemas/mp_fields/SUPPLIERFORQUOTATIONREQUESTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour SUPPLIERFORQUOTATIONREQUESTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="SUPPLIERFORQUOTATIONREQUESTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QUOTATIONREQUESTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SUPPLIERID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SUPPLIERFORQUOTATIONREQUESTID_Type", propOrder = {
    "quotationrequestid",
    "supplierid"
})
public class SUPPLIERFORQUOTATIONREQUESTID_Type {

    @XmlElement(name = "QUOTATIONREQUESTID", required = true)
    protected QUOTATIONREQUESTID_Type quotationrequestid;
    @XmlElement(name = "SUPPLIERID", required = true)
    protected SUPPLIERID_Type supplierid;

    /**
     * Obtient la valeur de la propriété quotationrequestid.
     * 
     * @return
     *     possible object is
     *     {@link QUOTATIONREQUESTID_Type }
     *     
     */
    public QUOTATIONREQUESTID_Type getQUOTATIONREQUESTID() {
        return quotationrequestid;
    }

    /**
     * Définit la valeur de la propriété quotationrequestid.
     * 
     * @param value
     *     allowed object is
     *     {@link QUOTATIONREQUESTID_Type }
     *     
     */
    public void setQUOTATIONREQUESTID(QUOTATIONREQUESTID_Type value) {
        this.quotationrequestid = value;
    }

    /**
     * Obtient la valeur de la propriété supplierid.
     * 
     * @return
     *     possible object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public SUPPLIERID_Type getSUPPLIERID() {
        return supplierid;
    }

    /**
     * Définit la valeur de la propriété supplierid.
     * 
     * @param value
     *     allowed object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public void setSUPPLIERID(SUPPLIERID_Type value) {
        this.supplierid = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/SUPPLIERFORQUOTATIONREQUESTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for SUPPLIERFORQUOTATIONREQUESTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SUPPLIERFORQUOTATIONREQUESTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QUOTATIONREQUESTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SUPPLIERID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SUPPLIERFORQUOTATIONREQUESTID_Type", propOrder = {
    "quotationrequestid",
    "supplierid"
})
public class SUPPLIERFORQUOTATIONREQUESTID_Type {

    @XmlElement(name = "QUOTATIONREQUESTID", required = true)
    protected QUOTATIONREQUESTID_Type quotationrequestid;
    @XmlElement(name = "SUPPLIERID", required = true)
    protected SUPPLIERID_Type supplierid;

    /**
     * Gets the value of the quotationrequestid property.
     * 
     * @return
     *     possible object is
     *     {@link QUOTATIONREQUESTID_Type }
     *     
     */
    public QUOTATIONREQUESTID_Type getQUOTATIONREQUESTID() {
        return quotationrequestid;
    }

    /**
     * Sets the value of the quotationrequestid property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUOTATIONREQUESTID_Type }
     *     
     */
    public void setQUOTATIONREQUESTID(QUOTATIONREQUESTID_Type value) {
        this.quotationrequestid = value;
    }

    /**
     * Gets the value of the supplierid property.
     * 
     * @return
     *     possible object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public SUPPLIERID_Type getSUPPLIERID() {
        return supplierid;
    }

    /**
     * Sets the value of the supplierid property.
     * 
     * @param value
     *     allowed object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public void setSUPPLIERID(SUPPLIERID_Type value) {
        this.supplierid = value;
    }

}
